"""Easily find and query AST elements by using CSS Selector-like syntax"""

from .main import AstSelector

__version__ = "0.1.1"
__all__ = ["AstSelector"]
